How to guides
=================
Explore the following how-to guides to accomplish common tasks with the HySOM package

.. toctree::
   :maxdepth: 1

   How to add a custom (Distance, Neighborhood or Decay) function <../tutorials/tutorials>
   
   How to find the best hyperparameters for your dataset <../tutorials/tutorials>
   
   How to train your own C-Q map <../tutorials/tutorials>
